{#- No context variables needed — this is static config -#}
{
  "hooks": {
    "SessionStart": [
      {
        "hooks": [
          {
            "type": "command",
            "command": "bash scripts/ensure-mcp.sh"
          }
        ]
      }
    ]
  }
}
