{#- Context variables:
   - company: str (e.g., "ACME Bank")
   - industry: str (e.g., "fsi")
   - catalog: str (e.g., "acme_fsi_demo")
   - bundle_name: str (e.g., "acme-bank-fsi-demo")
   - app_name: str (e.g., "acme-bank-fsi-app")
   - warehouse_id: str
   - workspace_host: str
   - databricks_profile: str | None
   - lakebase_url: str | None
   - notification_email: str
   - demo_description: str
-#}
bundle:
  name: {{ bundle_name }}

include:
  - resources/**/*.yml

variables:
  warehouse_id:
    description: SQL Warehouse ID for dashboards and Genie
    default: "{{ warehouse_id }}"

  catalog:
    description: Unity Catalog name
    default: {{ catalog }}

  notification_email:
    description: Email for job notifications
    default: {{ notification_email }}

  pipeline_target_schema:
    description: Default target schema for DLT pipeline (set after Phase 0 planning)
    default: "default"

  schema:
    description: Default schema for ML training (set after Phase 0 planning)
    default: "default"

targets:
  dev:
    mode: development
    default: true
    workspace:
      host: {{ workspace_host }}
{% if databricks_profile %}      profile: {{ databricks_profile }}
{% endif %}
    permissions:
      - user_name: {{ notification_email }}
        level: CAN_MANAGE

    run_as:
      user_name: {{ notification_email }}

  prod:
    mode: production
    workspace:
      host: {{ workspace_host }}
      root_path: /Workspace/.bundles/prod/${bundle.name}
{% if databricks_profile %}      profile: {{ databricks_profile }}
{% endif %}
    permissions:
      - user_name: {{ notification_email }}
        level: CAN_MANAGE

    run_as:
      user_name: {{ notification_email }}
