{#- Context variables: none needed — universal deps -#}
# Python dependencies for Databricks notebooks
# Referenced by job environment specs in resources/jobs/*.yml
faker>=28.0.0
pyarrow>=14.0.0
numpy>=1.26.0
pandas>=2.1.0
python-dateutil>=2.8.0
